==> haskell-memotrie-0.6.9-31-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-memotrie.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: MemoTrie
version: 0.6.9
id: MemoTrie-0.6.9-B9aIkhH4r4rKjZ1MXXrCtT
key: MemoTrie-0.6.9-B9aIkhH4r4rKjZ1MXXrCtT
license: BSD-3-Clause
copyright: (c) 2008-2016 by Conal Elliott
maintainer: conal@conal.net
author: Conal Elliott
stability: experimental
homepage: https://github.com/conal/MemoTrie
synopsis: Trie-based memo functions
description:
    MemoTrie provides a basis for memoized functions over some domains,
    using tries.  It'\''s based on ideas from Ralf Hinze and code from
    Spencer Janssen. Generic support thanks to Sam Boosalis.
    .
    Project wiki page: <http://haskell.org/haskellwiki/MemoTrie>
    .
    &#169; 2008-2016 by Conal Elliott; BSD3 license.
category: Data
abi: f41d87977faedf4baa8f3ebcc364f77a
exposed: True
exposed-modules:
    Data.MemoTrie
import-dirs: /usr/lib/ghc-8.6.5/site-local/MemoTrie-0.6.9
library-dirs: /usr/lib/ghc-8.6.5/site-local/MemoTrie-0.6.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/MemoTrie-0.6.9
hs-libraries: HSMemoTrie-0.6.9-B9aIkhH4r4rKjZ1MXXrCtT
depends:
    base-4.12.0.0 newtype-generics-0.5.3-GWdkBLw8hs31J4EzWBTwGn
haddock-interfaces: /usr/share/doc/haskell-memotrie/html/MemoTrie.haddock
haddock-html: /usr/share/doc/haskell-memotrie/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-memotrie-0.6.9-33-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-memotrie.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: MemoTrie
version: 0.6.9
id: MemoTrie-0.6.9-2BPq10PpgqvA6G5k1AfAM6
key: MemoTrie-0.6.9-2BPq10PpgqvA6G5k1AfAM6
license: BSD-3-Clause
copyright: (c) 2008-2016 by Conal Elliott
maintainer: conal@conal.net
author: Conal Elliott
stability: experimental
homepage: https://github.com/conal/MemoTrie
synopsis: Trie-based memo functions
description:
    MemoTrie provides a basis for memoized functions over some domains,
    using tries.  It'\''s based on ideas from Ralf Hinze and code from
    Spencer Janssen. Generic support thanks to Sam Boosalis.
    .
    Project wiki page: <http://haskell.org/haskellwiki/MemoTrie>
    .
    &#169; 2008-2016 by Conal Elliott; BSD3 license.
category: Data
abi: b807745b59c5d2b382070049069a642f
exposed: True
exposed-modules:
    Data.MemoTrie
import-dirs: /usr/lib/ghc-8.6.5/site-local/MemoTrie-0.6.9
library-dirs: /usr/lib/ghc-8.6.5/site-local/MemoTrie-0.6.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/MemoTrie-0.6.9
hs-libraries: HSMemoTrie-0.6.9-2BPq10PpgqvA6G5k1AfAM6
depends:
    base-4.12.0.0 newtype-generics-0.5.3-AV43oaXa2XzIqNO5fCKrpE
haddock-interfaces: /usr/share/doc/haskell-memotrie/html/MemoTrie.haddock
haddock-html: /usr/share/doc/haskell-memotrie/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
